@@ -18,7 +18,9 @@ shinyUI(fluidPage(
       checkboxInput('arg_comment', 'Preserve comments', TRUE),
       checkboxInput('arg_blank', 'Preserve blank lines', TRUE),
       checkboxInput('arg_assign', 'Replace = with <-', FALSE),
+      checkboxInput('arg_anl', 'Start function arguments on a new line', FALSE),
       checkboxInput('arg_brace', 'Put { on a new line', FALSE),
+      checkboxInput('arg_wrap', 'Wrap comments', TRUE),
       numericInput ('arg_indent', 'Number of spaces for indentation', 4, min = 0),
       radioButtons('width_type', 'Line width type', c('minimum', 'maximum'), inline = TRUE),
       numericInput ('arg_width', 'Line width value', 70, min = 20, max = 500),
